import { PublicKey } from '@dxos/keys';
import { type Credential, type SpaceMember, type ProfileDocument } from '@dxos/protocols/proto/dxos/halo/credentials';
import { type AsyncCallback, Callback } from '@dxos/util';
export interface MemberInfo {
    key: PublicKey;
    credential: Credential;
    assertion: SpaceMember;
    removed: boolean;
    profile?: ProfileDocument;
}
/**
 * Tracks the list of members (with roles) for the space.
 * Provides a list of admitted feeds.
 */
export declare class MemberStateMachine {
    private readonly _spaceKey;
    private _creator;
    /**
     * Member IDENTITY key => info
     */
    private _members;
    readonly onMemberAdmitted: Callback<AsyncCallback<MemberInfo>>;
    constructor(_spaceKey: PublicKey);
    get creator(): MemberInfo | undefined;
    get members(): ReadonlyMap<PublicKey, MemberInfo>;
    getRole(member: PublicKey): SpaceMember.Role | undefined;
    /**
     * Processes the SpaceMember credential.
     * Assumes the credential is already pre-verified and the issuer has been authorized to issue credentials of this type.
     */
    process(credential: Credential): Promise<void>;
    onRevoked(revoked: Credential, revocation: Credential): Promise<void>;
}
//# sourceMappingURL=member-state-machine.d.ts.map